###Social Life of Open Data: Exploring practices to set the Data Literacy Needs
##Juliana Raffaghelli - Stefania Manca
#Research Notebook: https://tinyurl.com/v29a3mh

##Research Aim: 
#Uncover current social practices around open data, 
#to highlight data literacy state and future needs.
#==================================================

##Preparing the workspace

setwd("C:/Users/Asus/Google Drive/1 - Pubblicazioni e Presentazioni/!2019/SOCIAL-LIFE_OD_2PHASE")
slodb <- read.csv("V9_ANON.csv")
View(slodb)
str(slodb)

slodb$Quality <- as.factor(slodb$Quality) #convert to factor "Quality"
slodb$RGScore <- as.numeric(slodb$RGScore) #convert to numeric "RGScore" etc.
slodb$CASE_ID <- as.factor (slodb$CASE_ID)
slodb$OD.readsgroup <- as.factor (slodb$OD.readsgroup)

summary(slodb)



##RQ1: Which is the social life of open data  within ResearchGate? 
#Social Life is considered in terms of view and citations, 
#given a number of characteristics of the researchers producing this datasets
# Descriptive Statistics
slodb.quan <- data.frame(slodb$OD_reads, slodb$X_Citations, slodb$LR_reads, slodb$LR_citations)
slodb.qual <- data.frame (slodb$Gender, slodb$d_field, slodb$region, slodb$Profile_Position, slodb$RGScore_grouped, slodb$Quality)
pairs(slodb.quan)
pairs(slodb.qual)
summarytools::descr(slodb.quan)
summarytools::descr(slodb.quan, transpose = TRUE)
summary(slodb.qual)
summary(slodb$Profile_Position)
summary(slodb$RGScore_grouped)
summary(slodb$Quality)


#Graphics
Publication_Reads <- (slodb$LR_reads)
PubReads_Median <- median(slodb$LR_reads)
Publication_citations <- (slodb$LR_citations)
OpenData_Reads <- (slodb$OD_reads)
ODReads_Median <- median(slodb$OD_reads)
OD_Quality <- slodb$Quality
OD_qUALITY <- na.omit(OD_Quality)
OpenData_Citations <- (slodb$X_Citations)
OD_Citations_Median <- median(slodb$X_Citations)
Scientific_Domain <- slodb$d_field
Gender <- slodb$Gender
Region <- slodb$region
Position <- slodb$Profile_Position
RGSc <- slodb$RGScore_grouped

#Scatterplot
install.packages("ggplot2")
library(ggplot2)
library(gridExtra)
install.packages("Hmisc")
library(Hmisc)
p1 <- ggplot(slodb, aes(OpenData_Reads,Publication_Reads)) + geom_point(data=slodb, na.rm=TRUE)
p2 <- ggplot(slodb, aes(OpenData_Reads,Publication_Reads, color= OD_Quality)) + geom_point(data=slodb, na.rm=TRUE)
p3 <- ggplot(slodb, aes(OpenData_Citations,Publication_Reads)) + geom_point(data=slodb, na.rm=TRUE)
p4 <- ggplot(slodb, aes(OpenData_Citations,Publication_Reads, color= OD_Quality)) + geom_point(data=slodb, na.rm=TRUE)
p5 <- ggplot(slodb, aes(OpenData_Citations,OpenData_Reads)) + geom_point(data=slodb, na.rm=TRUE)
p6 <- ggplot(slodb, aes(OpenData_Citations,OpenData_Reads, color= OD_Quality)) + geom_point(data=slodb, na.rm=TRUE)


grid.arrange(p1, p2, p3, p4, p5, p6, nrow = 3)

##Plot of interesting relationships
#eliminate outliers

install.packages("ggstatsplot")
library(ggstatsplot)
boxplot(slodb,
               OpenData_Reads, outlier.tagging = TRUE)
Q <- quantile(OpenData_Reads, probs=c(.0, .95), na.rm = FALSE)
iqr <- IQR(OpenData_Reads)
iqr
up <-  Q[2]+1.5*iqr # Upper Range  
low<- Q[1]-1.5*iqr # Lower Range
ODRb <- subset(slodb, OpenData_Reads > (Q[1] - 1.5*iqr) & OpenData_Reads < (Q[2]+1.5*iqr))
View(ODRb)
summary(ODRb)

boxplot(ODRb,
        ODRb$LR_reads, outlier.tagging = TRUE)
Q <- quantile(ODRb$LR_reads, probs=c(.0, .95), na.rm = FALSE)
iqr <- IQR(ODRb$LR_reads)
iqr
up <-  Q[2]+1.5*iqr # Upper Range  
low<- Q[1]-1.5*iqr # Lower Range
ODRc <- subset(ODRb, ODRb$LR_reads > (Q[1] - 1.5*iqr) & ODRb$LR_reads < (Q[2]+1.5*iqr))
View(ODRc)
summary(ODRc)
ODRcLRreads <- data.frame(ODRc$d_field, ODRc$region, ODRc$Gender, ODRc$LR_reads, ODRc$OD_reads )
pairs(ODRcLRreads)
ODRcLRxODR <- data.frame(ODRc$Quality, ODRc$LR_reads, ODRc$LR_citations, ODRc$OD_reads, ODRc$X_Citations)
pairs(ODRcLRxODR)
  
#LRRead-LRCitation
LRR.LRC <- ggplot(ODRc, aes(x = LR_reads, y = LR_citations))
# Scatter plot with regression line
LRR.LRC + geom_point()+
  geom_smooth(method = "lm")

#LR-OD Read
LR.ODRD <- ggplot(ODRc, aes(x = LR_reads, y = OD_reads))
# Scatter plot with regression line
LR.ODRD + geom_point()+
  geom_smooth(method = "lm")

#LR-OD Citations
LR.ODCIT<- ggplot(ODRc, aes(x = LR_reads , y = X_Citations))
# Scatter plot with regression line
LR.ODCIT + geom_point()+
  geom_smooth(method = "lm")


#Literature ReadxCitations x Gender
LRR.LRC  + geom_point(aes(color = Gender, shape = Gender))+
  geom_smooth(aes(color = Gender, fill = Gender), 
              method = "lm", fullrange = TRUE) +
  facet_wrap(~Gender) +
  scale_color_manual(values = c("#00AFBB", "#E7B800"))+
  scale_fill_manual(values = c("#00AFBB", "#E7B800")) +
  theme_bw()

#Literature ReadxCitations x Disciplinary Field
LRR.LRC + geom_point(aes(color = d_field, shape =d_field))+
  geom_smooth(aes(color = d_field, fill = d_field), 
              method = "lm", fullrange = TRUE) +
  facet_wrap(~d_field) +
  scale_color_manual(values = c("#00AFBB", "#E7B800", "#FC4E07", "#CC6677","#2DA17E" ))+
  scale_fill_manual(values = c("#00AFBB", "#E7B800", "#FC4E07", "#CC6677","#2DA17E" )) +
  theme_bw()

#Literature reading x Open Data Reading x Gender
LR.ODRD  + geom_point(aes(color = Gender, shape = Gender))+
  geom_smooth(aes(color = Gender, fill = Gender), 
              method = "lm", fullrange = TRUE) +
  facet_wrap(~Gender) +
  scale_color_manual(values = c("#00AFBB", "#E7B800"))+
  scale_fill_manual(values = c("#00AFBB", "#E7B800")) +
  theme_bw()

#Literature reading x Open Data Reading x Disciplinary Field
LR.ODRD  + geom_point(aes(color = d_field, shape =d_field))+
  geom_smooth(aes(color = d_field, fill = d_field), 
              method = "lm", fullrange = TRUE) +
  facet_wrap(~d_field) +
  scale_color_manual(values = c("#00AFBB", "#E7B800", "#FC4E07", "#CC6677","#2DA17E" ))+
  scale_fill_manual(values = c("#00AFBB", "#E7B800", "#FC4E07", "#CC6677","#2DA17E" )) +
  theme_bw()

LR.ODRD + geom_point(aes(color = Gender, size = OD_reads), alpha = 0.5) +
  scale_color_manual(values = c("#00AFBB", "#E7B800")) +
  scale_size(range = c(0.5, 12))  # Adjust the range of points size

LR.ODRD + geom_point(aes(color = Gender, size = RGScore), alpha = 0.5) +
  scale_color_manual(values = c("#00AFBB", "#E7B800")) +
  scale_size(range = c(0.5, 12))  # Adjust the range of points size

LRR.LRC  + geom_point(aes(color = d_field, size = RGScore), alpha = 0.5) +
  scale_color_manual(values = c("#00AFBB", "#E7B800", "#FC4E07", "#CC6677","#2DA17E")) +
  scale_size(range = c(0.5, 12))  # Adjust the range of points size

#barplots
p7 <- (ggplot(data=slodb, 
                  aes(x=Gender, y=ODReads_Median,
                  fill= Gender))+        # colori 
                  geom_bar(stat="identity") +
                  guides(fill=FALSE) + 
                  ggtitle("OD readings x Gender")) #Titolo
         
p7 

p8 <- (ggplot(data=slodb, 
              aes(x=Scientific_Domain, y=ODReads_Median,
                  fill= Scientific_Domain))+        # colori         
         geom_bar(stat="identity") +
         guides(fill=FALSE) + 
         ggtitle("OD readings x Domain")) #Titolo
p8 

p9 <- (ggplot(data=slodb, 
              aes(x=Region, y=ODReads_Median,
                  fill= Region))+        # colori         
         geom_bar(stat="identity") +
         guides(fill=FALSE) + 
         ggtitle("OD readings x Region")) #Titolo

p9+ coord_flip()

p10 <- (ggplot(data=slodb, 
              aes(x=Position, y=ODReads_Median,
                  fill= Position))+        # colori         
         geom_bar(stat="identity") +
         guides(fill=FALSE) + 
         ggtitle("OD readings x Position")) #Titolo

p10+ coord_flip()


#===============================================================================================

###Inferential Statistics ALL
##RQ1: Which is the social life of OD?

##Simple Correlation (Non-Parametric)

# A- Are dataset and publication readings associated?
cor.test(Publication_Reads,OpenData_Reads, method = "spearman") #n-s
cor.test(ODRc$LR_reads,ODRc$OD_reads, method = "spearman") #n-s

# B- Are dataset and publication citations associated?
cor.test(Publication_citations, OpenData_Citations) #n-s
cor.test(ODRc$LR_citations,ODRc$X_Citations) #n-s

# C- Are publication readings associated with publication citations?
cor.test(Publication_Reads, Publication_citations, method="spearman") #significant

# D- Are open data readings associated with open data citations?
cor.test(OpenData_Reads, OpenData_Citations, method="spearman")#significant
cor.test(ODRc$OD_reads, ODRc$X_Citations, method="spearman") #n-s


#Apparently LR reads predict OD readings and OD reads are a predictor of OD citations.
#LR readings do not predict OD citations, nor do LR reads predict LR citations.


## B- Does Region, RG Score, Gender and Location predict OD readings or citations?


##Simple regression

#Reads and Citations for the Publications

summary(lm(LR_citations ~ d_field, data=slodb)) #NO-S
summary(lm(LR_citations ~ region, data=slodb)) #NO_S
summary(lm(LR_citations ~ Gender, data=slodb)) #significant
summary (lm(LR_citations ~ RGScore_grouped, data=slodb)) #NO-S 
summary (lm (LR_citations ~ Profile_Position,data=slodb)) #NO-S
summary (lm(LR_citations ~ Quality,data=slodb)) #NO-S

summary(lm(LR_reads ~ d_field, data=slodb)) #natural sciences slightly significant at 0.10
summary(lm(LR_reads ~ region, data=slodb)) #NO_S
summary(lm(LR_reads ~ Gender, data=slodb)) #NO_S
summary (lm(LR_reads ~ RGScore_grouped, data=slodb)) #NO-S
summary (lm (LR_reads ~ Profile_Position,data=slodb)) #NO-S
summary (lm(LR_reads ~ Quality,data=slodb)) #Significant for Q3!

#Citations are connected (very weakly, tough) to gender (males prevailing) 
#and the type of profile/position (retired scholars and Research Practitioners coordinators)


#Reads and Citations for the Open Data

summary(lm(OD_reads ~ d_field, data=ODRc)) #NO-S
summary(lm(OD_reads ~ region, data=ODRc)) #NO_S
summary(lm(OD_reads ~ Gender, data=ODRc)) #NO_S
summary (lm(OD_reads ~ ODRc$RGScore_grouped, data=ODRc)) #Significant at .01 for grouped 31 or more.
summary (lm (OD_reads ~ Profile_Position,data=ODRc)) #NO-S
summary (lm(OD_reads ~ Quality,data=ODRc)) #Significant for Q1!

summary(lm(X_Citations ~ d_field, data=ODRc)) #p-value is slightly significant, weighted by Formal Sciences 
summary(lm(X_Citations ~ region, data=ODRc)) #NO_S
summary(lm(X_Citations ~ Gender, data=ODRc)) #NO_S
summary (lm(X_Citations ~ RGScore_grouped, data=ODRc)) #Significant at .05 for males
summary (lm (X_Citations ~ Profile_Position,data=ODRc)) #NO-S
summary (lm(X_Citations ~ Quality,data=ODRc)) #N-S


##Logistic Regression
#Prepare: Create a vector with only two values to prepare the analysis
LR_citbin <- slodb$LR_citations > 0 #Vector with LR Citations V/F
head(LR_citbin)
LR_readbin <- slodb$LR_reads > 0 #Vector with Reads V/F
head(LR_readbin)
OD_citbin <- slodb$X_Citations > 0 #Vector with OD Citations V/F
head(OD_citbin)
OD_readbin <- slodb$OD_reads > 0 #Vector with OD Reads V/F
head(OD_readbin)

#New Quality and RG-SCore
slodb$Quality <- as.numeric(slodb$Quality) #convert to numeric "Quality"
Q_bin <- slodb$Quality > 0 #Vector with Q Reads V/F
RGScore_bin <- slodb$RGScore > 100 #Vector with Q Reads V/F


#Run: Logistic Regression
#Over parameters found significant at the simple regression

#LR Citations x Gender
table(LR_citbin, slodb$Gender) #Explore distribution
summary(glm(LR_citbin ~ Gender, data=slodb, family="binomial")) #N-S

#LR Citations x quality of OD
table(LR_citbin, slodb$Quality) #Explore distribution
summary(glm(LR_citbin ~ Quality, data=slodb, family="binomial")) #N-S

#OD Citations x Disciplinary Field
table(OD_citbin, slodb$d_field) #Explore distribution
summary(glm(OD_citbin ~ d_field, data=slodb, family="binomial")) #S for social sciences

#OD Citations x Quality
table(OD_citbin, slodb$Quality) #Explore distribution
summary(glm(OD_citbin ~ Quality, data=slodb, family="binomial")) #slightly significant at 0.01 for Q3


#OD Reads x Quality
table(OD_readbin, slodb$Quality) #Explore distribution
summary(glm(OD_readbin ~ Quality, data=slodb, family="binomial")) #N-S

chisq.test(table(OD_readbin, slodb$Quality)) #Chisquare on the distribution is S (considering the strong weight of 0 reads)
fisher.test(table(OD_readbin, slodb$Quality ))

#OD Reads x Gender
table(OD_readbin, slodb$Gender) #Explore distribution
summary(glm(OD_readbin ~ Gender, data=slodb, family="binomial")) #N-S

#OD Reads x d_field
table(OD_readbin, slodb$d_field) #Explore distribution
summary(glm(OD_readbin ~ d_field, data=slodb, family="binomial")) #N-S

#Logistic Regression - Including more variables in the model
install.packages("car")

#OD READS AND CITATIONS 
#Logistic Regression
Model1 <- (glm(OD_citbin ~ Gender + region + d_field + Quality + RGScore_grouped + Profile_Position + slodb$OD.readsgroup.1 + slodb$LR_readsgrouped, data=slodb))
summary(Model1)
car::vif(Model1)
Model2 <- (glm(OD_citbin ~ d_field + Quality + slodb$OD.readsgroup.1,  data=slodb))
summary (Model2)
car::vif(Model2)

ModelChi1 <- Model1$null.deviance - Model1$deviance 
ModelChi1
chidf1 <- Model1$df.null - Model1$df.residual
chidf1
chisq.prob1 <- 1-pchisq(ModelChi1, chidf1)
chisq.prob1
R2.ODcit1 <- ModelChi1/Model1$null.deviance
R2.ODcit1
exp(Model1$coefficients)
exp(confint(Model1))

ModelChi2 <- Model2$null.deviance - Model2$deviance 
ModelChi2
chidf2 <- Model2$df.null - Model2$df.residual
chidf2
chisq.prob2 <- 1-pchisq(ModelChi2, chidf2)
chisq.prob2
R2.ODcit2 <- ModelChi2/Model2$null.deviance
R2.ODcit2
exp(Model2$coefficients)
exp(confint(Model2))


Model1b <- (glm(OD_readbin ~ Quality + RGScore_grouped, data=slodb))
summary(Model1b)


ModelChi1b <- Model1b$null.deviance - Model1b$deviance 
ModelChi1b
chidf1b <- Model1b$df.null - Model1b$df.residual
chidf1b
chisq.prob1b <- 1-pchisq(ModelChi1b, chidf1b)
chisq.prob1b
R2.ODread <- ModelChi1b/Model1b$null.deviance
R2.ODread
exp(Model1b$coefficients)
exp(confint(Model1b))


#LR READS AND CITATIONS 
#Logistic Regression
Model1e <- (glm(LR_readbin ~ Gender + region + d_field + Quality + RGScore_grouped + Profile_Position + slodb$OD.readsgroup.1, data=slodb))
summary(Model1e)
Model2e <- (glm(LR_readbin ~ Profile_Position + slodb$OD.readsgroup.1,  data=slodb))
summary (Model2e)

ModelChi2e <- Model2e$null.deviance - Model2e$deviance 
ModelChi2e
chidf2e <- Model2e$df.null - Model2e$df.residual
chidf2e
chisq.prob2e <- 1-pchisq(ModelChi2e, chidf2e)
chisq.prob2e
R2.LR2e <- ModelChi2e/Model2e$null.deviance
R2.LR2e
exp(Model2e$coefficients)
exp(confint(Model2e))



Model1b <- (glm(OD_readbin ~ Quality + RGScore_grouped, data=slodb))
summary(Model1b)


Model1f <- (glm(LR_citbin ~ Gender + region + d_field + Quality + RGScore_grouped + Profile_Position + slodb$OD.readsgroup.1, data=slodb))
summary(Model1f)
Model2f <- (glm(LR_citbin ~ Region + d_field,  data=slodb))
summary (Model2f)

ModelChi1f <- Model1f$null.deviance - Model1f$deviance 
ModelChi1f
chidf1f <- Model1f$df.null - Model1f$df.residual
chidf1f
chisq.prob1f <- 1-pchisq(ModelChi1f, chidf1f)
chisq.prob1f
R2.LR1f <- ModelChi1f/Model1f$null.deviance
R2.LR1f
exp(Model1f$coefficients)
exp(confint(Model1f))



#QUALITY AND RGSCORE AS RESPONSE VARIABLE

Model1c <- (glm(Q_bin ~  slodb$region + slodb$LR_readsgrouped , data=slodb))
summary(Model1c)

ModelChi1c <- Model1c$null.deviance - Model1c$deviance 
ModelChi1c
chidf1c <- Model1c$df.null - Model1c$df.residual
chidf1c
chisq.prob1c <- 1-pchisq(ModelChi1c, chidf1c)
chisq.prob1c
R2.ODQ <- ModelChi1c/Model1c$null.deviance
R2.ODQ
exp(Model1c$coefficients)
exp(confint(Model1c))

Model1d <- (glm(RGScore_bin ~ Gender + region + d_field +  Profile_Position + slodb$LR_readsgrouped + slodb$OD.readsgroup.1 + slodb$X_Citations, data=slodb))
summary(Model1d)

ModelChi1d <- Model1d$null.deviance - Model1d$deviance 
ModelChi1d
chidf1d <- Model1d$df.null - Model1d$df.residual
chidf1d
chisq.prob1d <- 1-pchisq(ModelChi1d, chidf1d)
chisq.prob1d
R2.RGSc <- ModelChi1d/Model1d$null.deviance
R2.RGSc
exp(Model1d$coefficients)
exp(confint(Model1d))




##====================================
##Cluster Analysis

library(cluster)
library(clustertend)
library(factoextra)
library(plyr)

##Cluster Analysis WO Outliers

#Prepare dataset and initial modelling
PubReads <- ODRc$LR_reads
ODReads <- ODRc$OD_reads
slod.clusb <- data.frame(PubReads, ODReads)
slod.clusb <- scale(slod.clusb)
slod.clusb <- na.omit(slod.clusb)
#OtherTrials
slody <- data.frame (ODRc$d_field,ODRc$OD_reads, ODRc$LR_reads)
slody <- na.omit(slody)
slodz <- data.frame(ODRc$RGScore_grouped, ODRc$LR_reads, ODRc$OD_reads)
slodz <- na.omit(slodz)
ODRcLRxODR <- na.omit(ODRcLRxODR)

model <- kmeans(ODRcLRxODR, centers = 3)
model.clustered <- mutate(ODRcLRxODR, cluster = model$cluster)
print(model.clustered)
CLUSTER <- as.factor(model.clustered$cluster)
LR_reads <- model.clustered$ODRc.LR_reads
OD_reads <- model.clustered$ODRc.OD_reads
ggplot(model.clustered, aes(x = LR_reads, y = OD_reads, color = CLUSTER)) +
  geom_point()


##K-Means Clustering

#Preliminary analysis to see the possibility of forming clusters
fviz_pca_ind(prcomp(slod.clusb),title= "PCA SLOD", palette= "jco", geom="point", ggtheme=theme_classic(), legend="bottom")
#One dimension explains the 90% of variability!!!. There is apparantly another component explained.

##Hopkins Test
hopkins <- hopkins (slod.clusb, n=nrow(slod.clusb)-1)
hopkins #it gives only 1 cluster

#Elbow Method

set.seed(123)

fviz_nbclust(slod.clusb, kmeans, method = "wss")

#Three clusters are optimal (take at look at the bend or "knee" in the plot)

#Silhouette Method
fviz_nbclust(slod.clusb, kmeans, method = "silhouette")
#Three clusters as highest silohuettes

set.seed(123)
clust.no <- kmeans(slod.clusb, 3, nstart=25)
print(clust.no)



# Inspect 'clusters'
str(clust.no)
summary(clust.no)
fviz_cluster(clust.no, data = slod.clusb)
table(clust.no$cluster, ODRc$Gender)
table(clust.no$cluster, ODRc$d_field)
table(clust.no$cluster, ODRc$region)
table(clust.no$cluster, ODRc$Quality)
table(clust.no$cluster, ODRc$RGScore_grouped)
table(clust.no$cluster,ODRc$Profile_Position)


#===============================
#Prepare dataset
slod.clusc <- data.frame(ODRc$LR_citations,ODRc$OD_reads)
slod.clusc <- scale(slod.clusc)
slod.clusc <- na.omit(slod.clusc)

##K-Means Clustering

#Preliminary analysis to see the possibility of forming clusters
fviz_pca_ind(prcomp(slod.clusc),title= "PCA SLOD", palette= "jco", geom="point", ggtheme=theme_classic(), legend="bottom")
#One dimension explains the 90% of variability!!!. There is apparantly another component explained.

##Hopkins Test
hopkins <- hopkins (slod.clusc, n=nrow(slod.clusc)-1)
hopkins #it gives only 1 cluster

#Elbow Method

set.seed(123)

fviz_nbclust(slod.clusc, kmeans, method = "wss")

#Three clusters are optimal (take at look at the bend or "knee" in the plot)

#Silhouette Method
fviz_nbclust(slod.clusc, kmeans, method = "silhouette")
#Three clusters as highest silohuettes

set.seed(123)
clust.no <- kmeans(slod.clusc, 3, nstart=25)
print(clust.no)

clust.no$cluster <- as.numeric (clust.no$cluster)
summary(clust.no$cluster)

# Inspect 'clusters'
str(clust.no)
summary(clust.no)
fviz_cluster(clust.no, data = slod.clusc)
table(clust.no$cluster, ODRc$Gender)
table(clust.no$cluster, ODRc$d_field)
table(clust.no$cluster, ODRc$region)
table(clust.no$cluster, ODRc$Quality)
table(clust.no$cluster, ODRc$RGScore_grouped)
table(clust.no$cluster,ODRc$Profile_Position)
